@@ -1,6 +1,7 @@
 /*
  * gnote
  *
+ * Copyright (C) 2010 Debarshi Ray
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -20,6 +21,8 @@
 
 #include <string.h>
 
+#include <glibmm.h>
+
 #include "tagmanager.hpp"
 #include "debug.hpp"
 #include "note.hpp"
@@ -73,7 +76,7 @@ namespace gnote {
 
     std::vector<std::string> splits;
     sharp::string_split(splits, normalized_tag_name, ":");
-    if ((splits.size() > 2) || sharp::string_starts_with(normalized_tag_name, Tag::SYSTEM_TAG_PREFIX)) {
+    if ((splits.size() > 2) || Glib::str_has_prefix(normalized_tag_name, Tag::SYSTEM_TAG_PREFIX)) {
       Glib::Mutex::Lock lock(m_locker);
       std::map<std::string, Tag::Ptr>::const_iterator iter = m_internal_tags.find(normalized_tag_name);
       if(iter != m_internal_tags.end()) {
@@ -104,7 +107,7 @@ namespace gnote {
 
     std::vector<std::string> splits;
     sharp::string_split(splits, normalized_tag_name, ":");
-    if ((splits.size() > 2) || sharp::string_starts_with(normalized_tag_name, Tag::SYSTEM_TAG_PREFIX)){
+    if ((splits.size() > 2) || Glib::str_has_prefix(normalized_tag_name, Tag::SYSTEM_TAG_PREFIX)){
       Glib::Mutex::Lock lock(m_locker);
       std::map<std::string, Tag::Ptr>::iterator iter;
       iter = m_internal_tags.find(normalized_tag_name);
